@@ -1,3 +1,5 @@
+import os
+import socket
 from pyage.core.inject import Inject
 
 class AddressProvider(object):
@@ -13,6 +15,6 @@ class Addressable(object):
     def __init__(self):
         super(Addressable, self).__init__()
         if hasattr(self, "name") and self.name:
-            self.address = self.name
+            self.address = self.name + "." + socket.gethostname() + "." + str(os.getpid())
         else:
             self.address = self.address_provider.generate_address(self)
\ No newline at end of file
